@@ -1,7 +1,7 @@
 /*
  * radio plugin for Xfce4.
  *
- * Copyright (c) 2006 Stefan Ott, All rights reserved.
+ * Copyright (c) 2006/2007 Stefan Ott, All rights reserved.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,17 +24,20 @@
 
 #include <ctype.h>
 #include <string.h>
+#include <unistd.h>
+#include <stdlib.h>
 
 #include "radio.h"
 
 #include <libxfcegui4/dialogs.h>
-
+#include <libxfcegui4/xfce-exec.h>
+#include <libxfce4util/libxfce4util.h>
 
 static int
 radio_get_signal (int fd)
 {
 	struct video_tuner vt;
-	int i, signal;
+	int signal;
 
 	memset (&vt, 0, sizeof (vt));
 	ioctl (fd, VIDIOCGTUNER, &vt);
@@ -55,7 +58,7 @@ update_signal_bar (radio_gui* data)
 		double signal = radio_get_signal (data->fd);
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR
 					(data->signal_bar), signal / 2);
-	
+
 		GdkColor color;
 		gdk_color_parse (signal > 1 ? COLOR_SIGNAL_HIGH :
 						COLOR_SIGNAL_LOW, &color);
@@ -262,7 +265,7 @@ rename_preset (GtkEditable* menu_item, void *pointer)
 static void
 add_preset_dialog (GtkEditable* menu_item, void *pointer)
 {
-        radio_gui* data = (radio_gui*) pointer;
+	radio_gui* data = (radio_gui*) pointer;
 	GtkWindow* win = GTK_WINDOW (gtk_widget_get_toplevel (data->box));
 	GtkWidget* dialog = gtk_dialog_new_with_buttons (_("Add preset"),
 				NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -327,7 +330,7 @@ parse_freq_and_tune (const char* freq_char, radio_gui* data)
 static void
 radio_tune_gui (GtkEditable *menu_item, void *pointer)
 {
-        radio_gui* data = (radio_gui*) pointer;
+	radio_gui* data = (radio_gui*) pointer;
 	GtkWindow* win = GTK_WINDOW (gtk_widget_get_toplevel (data->box));
 	GtkWidget* dialog = gtk_dialog_new_with_buttons (_("Tune radio"),
 				NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -355,7 +358,7 @@ radio_tune_gui (GtkEditable *menu_item, void *pointer)
 
 		const char* freq_char = gtk_entry_get_text (GTK_ENTRY (freq));
 		if (parse_freq_and_tune (freq_char, data)) break;
-	
+
 		GtkWidget* warn = gtk_message_dialog_new (win, 0,
 					GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 						_("Illegal frequency."));
@@ -390,7 +393,7 @@ remove_preset (GtkEditable* menu_item, void *pointer)
 	preset = pop_preset (find_preset_by_freq (data->freq, data), data);
 
 	XfceRc *rc;
-	if (rc = get_config_file_write_handle (data)) {
+	if ((rc = get_config_file_write_handle (data))) {
 		char buf[6];
 		sprintf(buf, "%d", preset->freq);
 
@@ -415,7 +418,7 @@ remove_preset (GtkEditable* menu_item, void *pointer)
 static void
 select_preset (GtkEditable* menu_item, void *pointer)
 {
-        radio_gui* data = (radio_gui*) pointer;
+	radio_gui* data = (radio_gui*) pointer;
 	GtkWidget* label = gtk_bin_get_child (GTK_BIN (menu_item));
 	const char* text = gtk_label_get_text (GTK_LABEL (label));
 	radio_preset* preset = find_preset_by_name (text, data);
@@ -635,7 +638,7 @@ plugin_control_new (XfcePanelPlugin *plugin)
 	radio_gui* plugin_data = create_gui();
 
 	plugin_data->plugin = plugin;
-	
+
 	plugin_data->on = FALSE;
 	plugin_data->freq = FREQ_INIT;
 	plugin_data->freqfact = 16;
@@ -645,7 +648,7 @@ plugin_control_new (XfcePanelPlugin *plugin)
 	plugin_data->scroll = CHANGE_FREQ;
 	plugin_data->timeout_id = 0;
 	plugin_data->tooltips = gtk_tooltips_new();
-	
+
 	update_label(plugin_data);
 
 	gtk_container_add (GTK_CONTAINER (plugin), plugin_data->ebox);
@@ -728,7 +731,6 @@ radio_plugin_create_options (XfcePanelPlugin *plugin, radio_gui *data)
 
 	g_signal_connect (dialog, "response",
 			G_CALLBACK (radio_plugin_dialog_response), data);
-	
 
 	table = gtk_table_new(4, 2, FALSE);
 	gtk_widget_show(table);
@@ -776,25 +778,25 @@ radio_plugin_create_options (XfcePanelPlugin *plugin, radio_gui *data)
 	gtk_widget_show (label);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4, GTK_FILL,
 								0, 0, 0);
-        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
 	command_entry = gtk_entry_new_with_max_length (MAX_COMMAND_LENGTH);
 	gtk_entry_set_text (GTK_ENTRY (command_entry), data->command);
 	gtk_widget_show (command_entry);
 	gtk_table_attach (GTK_TABLE (table), command_entry, 1, 2, 3, 4,
 					GTK_EXPAND | GTK_FILL, 0, 0, 0);
-	
+
 	label = gtk_label_new (_("Mouse scrolling changes"));
 	gtk_widget_show (label);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL,
 								0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	
+
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
 	gtk_table_attach (GTK_TABLE (table), hbox, 1, 2, 2, 3, GTK_FILL,
 							GTK_FILL, 0, 0);
-	
+
 	frequency_button = gtk_radio_button_new_with_label (NULL, 
 							_("frequency"));
 	gtk_widget_show (frequency_button);
@@ -845,7 +847,7 @@ static void
 write_config (XfcePanelPlugin *plugin, radio_gui *data)
 {
 	XfceRc *rc;
-	if (rc = get_config_file_write_handle (data)) {
+	if ((rc = get_config_file_write_handle (data))) {
 		xfce_rc_set_group	(rc, "radio plugin");
 
 		xfce_rc_write_entry	(rc, "dev", data->device);
@@ -856,7 +858,7 @@ write_config (XfcePanelPlugin *plugin, radio_gui *data)
 
 		xfce_rc_set_group	(rc, "presets");
 
-		radio_preset *preset = data->presets, *prev;
+		radio_preset *preset = data->presets;
 
 		char buf[6];
 
@@ -909,9 +911,9 @@ read_config (XfcePanelPlugin *plugin, radio_gui *data)
 		xfce_rc_set_group (rc, "presets");
 
 		while (*entry) {
-			if ((value = xfce_rc_read_entry (rc, *entry, NULL)) 
+			if ((value = xfce_rc_read_entry (rc, *entry, NULL))
 								&& *value) {
-				radio_preset *preset = 
+				radio_preset *preset =
 						malloc (sizeof (radio_preset));
 				preset->next = NULL;
 				strncpy(preset->name, value,
@@ -919,10 +921,9 @@ read_config (XfcePanelPlugin *plugin, radio_gui *data)
 				preset->freq = atoi (*entry);
 				append_to_presets (preset, data);
 			}
-			*entry++;
+			entry++;
 		}
 	}
-
 	g_strfreev (entries);
 }
 
@@ -933,7 +934,7 @@ radio_plugin_construct (XfcePanelPlugin *plugin)
 
 	radio_gui *data = plugin_control_new (plugin);
 	read_config (plugin, data);
-	
+
 	xfce_panel_plugin_menu_show_configure (plugin);
 
 	g_signal_connect (plugin, "configure-plugin",
